@@ -19,11 +19,11 @@
 #define LIBPLACEBO_CONFIG_H_
 
 // Increased any time the library changes in a fundamental/major way.
-#define PL_MAJOR_VER 5
+#define PL_MAJOR_VER 6
 
 // Increased any time the API changes. (Note: Does not reset when PL_MAJOR_VER
 // is increased)
-#define PL_API_VER 264
+#define PL_API_VER 338
 
 // Increased any time a fix is made to a given API version.
 #define PL_FIX_VER (pl_fix_ver())
@@ -39,11 +39,12 @@
 #define PL_HAVE_GL_PROC_ADDR 1
 #define PL_HAVE_GLSLANG 1
 #define PL_HAVE_LCMS 1
-#undef PL_HAVE_LIBDOVI
+#define PL_HAVE_LIBDOVI 1
 #define PL_HAVE_OPENGL 1
 #define PL_HAVE_SHADERC 1
 #define PL_HAVE_VK_PROC_ADDR 1
 #define PL_HAVE_VULKAN 1
+#define PL_HAVE_XXHASH 1
 
 
 // Extra compiler-specific stuff
@@ -67,15 +68,27 @@
 # endif
 #endif
 
-// C++ compatibility
-#ifndef PL_API_BEGIN
-# ifdef __cplusplus
-#  define PL_API_BEGIN extern "C" {
-#  define PL_API_END }
+#if defined(_WIN32) || defined(__CYGWIN__)
+# ifdef PL_EXPORT
+#  define PL_API __declspec(dllexport)
 # else
-#  define PL_API_BEGIN
-#  define PL_API_END
+#  ifndef PL_STATIC
+#   define PL_API __declspec(dllimport)
+#  else
+#   define PL_API
+#  endif
 # endif
+#else
+# define PL_API __attribute__ ((visibility ("default")))
+#endif
+
+// C++ compatibility
+#ifdef __cplusplus
+# define PL_API_BEGIN extern "C" {
+# define PL_API_END }
+#else
+# define PL_API_BEGIN
+# define PL_API_END
 #endif
 
 #ifndef __cplusplus
@@ -92,8 +105,8 @@
 
 PL_API_BEGIN
 
-int pl_fix_ver(void);
-const char *pl_version(void);
+PL_API int pl_fix_ver(void);
+PL_API const char *pl_version(void);
 
 PL_API_END
 
